camelot.camelot.view.proxy.queryproxy

Package camelot :: Package camelot :: Package view :: Package proxy :: Module queryproxy |
[hide private]
[frames] | no frames]

# Module queryproxy

source code

Proxies representing the results of a query

Classes | [hide private]
| QueryTableProxy The QueryTableProxy contains a limited copy of the data in the Elixir model, which is fetched from the database to be used as the model for a QTableView

Variables | [hide private]
| logger = `logging.getLogger('camelot.view.proxy.queryproxy')`